pub struct DockerStartArgs {
pub image: String,
pub env: BTreeMap<String, String>,
pub workdir: String,
pub name_hint: String,
}Expand description
Host-fn argument struct for hm_docker_start_container.
Fields
image: Stringenv: BTreeMap<String, String>workdir: Stringname_hint: StringTrait Implementations
Sourceimpl Clone for DockerStartArgs
impl Clone for DockerStartArgs
Sourcefn clone(&self) -> DockerStartArgs
fn clone(&self) -> DockerStartArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DockerStartArgs
impl Debug for DockerStartArgs
Sourceimpl<'de> Deserialize<'de> for DockerStartArgs
impl<'de> Deserialize<'de> for DockerStartArgs
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<DockerStartArgs, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<DockerStartArgs, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DockerStartArgs
impl JsonSchema for DockerStartArgs
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DockerStartArgs
impl PartialEq for DockerStartArgs
Sourcefn eq(&self, other: &DockerStartArgs) -> bool
fn eq(&self, other: &DockerStartArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DockerStartArgs
impl Serialize for DockerStartArgs
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for DockerStartArgs
impl StructuralPartialEq for DockerStartArgs