pub struct Pipeline {
pub version: String,
pub env: Option<BTreeMap<String, String>>,
pub default_image: Option<String>,
pub steps: Vec<Step>,
}Fields
version: StringMust equal "0" — bumping this is reserved for breaking
schema changes, none of which are scheduled. The v0 schema
gains optional fields in-place (see runner below).
env: Option<BTreeMap<String, String>>default_image: Option<String>steps: Vec<Step>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Pipeline
impl<'de> Deserialize<'de> for Pipeline
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Pipeline, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Pipeline, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Pipeline
impl JsonSchema for Pipeline
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for Pipeline
impl Serialize for Pipeline
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for Pipeline
impl StructuralPartialEq for Pipeline