pub struct PlanSummary {
pub step_count: usize,
pub chain_count: usize,
pub default_runner: String,
}Expand description
Compact summary of the resolved IR included in BuildStart. Lets
output formatters print a header without needing the full pipeline.
Fields
step_count: usizechain_count: usizedefault_runner: StringTrait Implementations
Sourceimpl Clone for PlanSummary
impl Clone for PlanSummary
Sourcefn clone(&self) -> PlanSummary
fn clone(&self) -> PlanSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PlanSummary
impl Debug for PlanSummary
Sourceimpl<'de> Deserialize<'de> for PlanSummary
impl<'de> Deserialize<'de> for PlanSummary
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<PlanSummary, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<PlanSummary, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PlanSummary
impl JsonSchema for PlanSummary
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PlanSummary
impl PartialEq for PlanSummary
Sourcefn eq(&self, other: &PlanSummary) -> bool
fn eq(&self, other: &PlanSummary) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PlanSummary
impl Serialize for PlanSummary
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for PlanSummary
impl StructuralPartialEq for PlanSummary