pub struct SocketHandle(pub u64);Expand description
Opaque socket handle returned by hm_unix_socket_connect. Bound
to the plugin instance that opened it.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for SocketHandle
impl Clone for SocketHandle
Sourcefn clone(&self) -> SocketHandle
fn clone(&self) -> SocketHandle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SocketHandle
impl Debug for SocketHandle
Sourceimpl<'de> Deserialize<'de> for SocketHandle
impl<'de> Deserialize<'de> for SocketHandle
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<SocketHandle, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<SocketHandle, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for SocketHandle
impl Hash for SocketHandle
Sourceimpl JsonSchema for SocketHandle
impl JsonSchema for SocketHandle
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourceimpl PartialEq for SocketHandle
impl PartialEq for SocketHandle
Sourcefn eq(&self, other: &SocketHandle) -> bool
fn eq(&self, other: &SocketHandle) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SocketHandle
impl Serialize for SocketHandle
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Copy for SocketHandle
impl Eq for SocketHandle
impl StructuralPartialEq for SocketHandle