Module subcommand
hm_
plugin_
sdk
0.0.1
Module subcommand
Module Items
Structs
Traits
In crate hm_
plugin_
sdk
hm_plugin_sdk
Module
subcommand
Structs

Subcommand
Input
Carried into the plugin’s subcommand entry point. The host has already parsed argv on the plugin’s behalf using the schema the plugin declared in its manifest.
Traits

Subcommand
Plugin